package com.ruoyi.oa.service;

import java.util.List;
import com.ruoyi.oa.domain.CmcProjectProgress;

/**
 * cmc项目进度Service接口
 * 
 * @author cmc
 * @date 2024-04-02
 */
public interface ICmcProjectProgressService 
{
    /**
     * 查询cmc项目进度
     * 
     * @param projectId cmc项目进度主键
     * @return cmc项目进度
     */
    public List<CmcProjectProgress> selectCmcProjectProgressByProjectId(String projectId);

    /**
     * 查询cmc项目进度列表
     * 
     * @param cmcProjectProgress cmc项目进度
     * @return cmc项目进度集合
     */
    public List<CmcProjectProgress> selectCmcProjectProgressList(CmcProjectProgress cmcProjectProgress);

    /**
     * 新增cmc项目进度
     * 
     * @param cmcProjectProgress cmc项目进度
     * @return 结果
     */
    public int insertCmcProjectProgress(CmcProjectProgress cmcProjectProgress);

    /**
     * 修改cmc项目进度
     * 
     * @param cmcProjectProgress cmc项目进度
     * @return 结果
     */
    public int updateCmcProjectProgress(CmcProjectProgress cmcProjectProgress);

    /**
     * 批量删除cmc项目进度
     * 
     * @param projectIds 需要删除的cmc项目进度主键集合
     * @return 结果
     */
    public int deleteCmcProjectProgressByProjectIds(String[] projectIds);

    /**
     * 删除cmc项目进度信息
     * 
     * @param projectId cmc项目进度主键
     * @return 结果
     */
    public int deleteCmcProjectProgressByProjectId(String projectId);
}
